#
# spec file for package infiniband-diags
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define git_ver -gitb2cfed8

Name:           infiniband-diags
Summary:        OpenFabrics Alliance InfiniBand Diagnostic Tools
License:        GPL-2.0 or BSD-2-Clause
Group:          Productivity/Networking/Diagnostic
Version:        1.6.6
Release:        2.3
Source0:        %{name}-%{version}%{git_ver}.tar.xz
Source1:        rdma-ndd.service
Patch2:         infiniband-diags-help_for_ibnodes.patch
Url:            http://www.openfabrics.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  glib2-devel
BuildRequires:  libibmad-devel
BuildRequires:  libibumad-devel
BuildRequires:  libibverbs-devel
BuildRequires:  libtool
BuildRequires:  libudev-devel
BuildRequires:  opensm-devel
BuildRequires:  pkg-config
BuildRequires:  python3-docutils
Requires:       perl = %{perl_version}

%define so_major 5

%description
diags provides IB diagnostic programs and scripts needed to diagnose an
IB subnet.

%package    -n libibnetdisc%{so_major}
Summary:        Infiniband Net Discovery runtime library
Group:          System/Libraries

%description -n libibnetdisc%{so_major}
This package contains the Infiniband Net Discovery runtime library needed
mainly by infiniband-diags.


%package devel
BuildRequires:  libibmad-devel
BuildRequires:  libibumad-devel
BuildRequires:  libibverbs-devel
BuildRequires:  opensm-devel
Requires:       %name = %version
Summary:        OpenIB InfiniBand Diagnostic Tools SDK
Group:          Development/Libraries/C and C++
Provides:       infiniband-diags:%{_libdir}/libibnetdisc.so

%description devel
diags provides IB diagnostic programs and scripts needed to diagnose an
IB subnet. This package contains all files needed for development.

%package       devel-static
Requires:       %name = %version
Summary:        Development package OpenIB InfiniBand Diagnostic Tools
Group:          Development/Libraries/C and C++

%description devel-static
diags provides IB diagnostic programs and scripts needed to diagnose an
IB subnet. This package contains the static library.

%package     -n rdma-ndd
Summary:        Daemon to manage RDMA Node Description
Group:          System Environment/Daemons
Requires:       %{name} = %{version}
# The udev rules in rdma need to be aware of rdma-ndd:
Conflicts:      rdma < 2.1
BuildRequires:  systemd
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

%description -n rdma-ndd
rdma-ndd is a system daemon which watches for rdma device changes and/or
hostname changes and updates the Node Description of the rdma devices based
on those changes.


%prep
%setup -q -n %{name}-%{version}
%patch2
# Avoid unnecessary rebuilds of the package
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/ibdiag_common.c

%build
autoreconf -fi
export CFLAGS="%{optflags}"
%configure --with-perl-installdir=%{perl_vendorarch} --enable-static
make %{?_smp_mflags} V=1

%install
make DESTDIR=%buildroot install
# systemd unit file
mkdir -p %{buildroot}%{_unitdir}
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}
rm -f %{buildroot}%{_sysconfdir}/init.d/rdma-ndd
ln -sfn /usr/sbin/service %{buildroot}/usr/sbin/rcrdma-ndd

%post -n libibnetdisc%{so_major} -p /sbin/ldconfig
%postun -n libibnetdisc%{so_major} -p /sbin/ldconfig

%pre -n rdma-ndd
%service_add_pre rdma-ndd.service

%preun -n rdma-ndd
%service_del_preun rdma-ndd.service

%post -n rdma-ndd
%service_add_post rdma-ndd.service

%postun -n rdma-ndd
%service_del_postun rdma-ndd.service

%files
%defattr(-, root, root)
%doc COPYING README ChangeLog
%config %{_sysconfdir}/infiniband-diags/error_thresholds
%dir %{_sysconfdir}/infiniband-diags
%config(noreplace) %{_sysconfdir}/infiniband-diags/*
%_sbindir/*
%exclude %{_sbindir}/rdma-ndd
%_mandir/man8/*
%exclude %{_mandir}/man8/rdma-ndd.8*
%_mandir/man3/*
%{perl_vendorarch}/IBswcountlimits.pm

%files -n libibnetdisc%{so_major}
%defattr(-, root, root)
%{_libdir}/*.so.*

%files devel
%defattr(-, root, root)
%{_includedir}/infiniband/*.h
%{_libdir}/*.so

%files devel-static
%defattr(-, root, root)
%{_libdir}/*.a
%{_libdir}/*.la

%files -n rdma-ndd
%defattr(-, root, root)
%{_sbindir}/rdma-ndd
%{_unitdir}/rdma-ndd.service
%{_mandir}/man8/rdma-ndd.8*

%changelog
* Mon Mar  7 2016 pth@suse.de
- Update to latest git version (fate#320027).
  For changes see the included ChangeLog.
- Include Changelog.
- Remove infiniband-diags-automake_foreign.patch and
  infiniband-diags-configure.patch as they aren't needed anymore.
- New sub package rdma-ndd, needed for the above fate.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Tue Feb 18 2014 pth@suse.de
- 1.6.4 uses configure.ac so remove the now bogus rename.
* Thu Feb 13 2014 pth@suse.de
- Update to 1.6.4 for fate#315488. Changes since 1.6.2 :
  * Revert "libibnetdisc/ibnetdisc.c: improve log information to stdout"
  * ibtracert.8.in: change default pre-built man page
  * infiniband-diags: Check node-name-map strings when querying by name
  * libibnetdisc/ibnetdisc.c: improve log information to stdout
  * libibnetdisc/ibnetdisc.c: fix insert of invalid lid 0xFFFF into
    lid_port hash_table
  * ibtracert.c: Add 'force' flag to man page
  * infiniband-diags/vendstat: Fix GeneralInfo SW version
  * ibportstate: on/off option is missing in help
  * iblinkinfo: Remove "-R" option from man page
  * ibaddr: Add missing -t option to manpage
  * ibdiag_sa.c: Output attribute ID in hex rather than decimal
  * get_lid_from_name(): Remove an unused variable
- Rename configure.in to configure.ac to shut up autoconf.
* Wed Jan 29 2014 pth@suse.de
- Change License to GPL-2.0 or BSD-3-Clause.
- Add COPYING to package.
* Tue Jan 21 2014 pth@suse.de
- Update to 1.6.2 from OFED 3.12 daily
- Fix configure.ac
- Add glib2-devel to BuildRequires as libibnetdisc needs it.
* Wed Jan 15 2014 pth@suse.de
- Enable build for s390x.
* Mon Feb 25 2013 pth@suse.de
- Make ibnodes output its own help (bnc#740144):
  infiniband-diags-help_for_ibnodes.patch
* Thu Sep 13 2012 pth@suse.de
- Make the package own /etc/infiniband-diags
- Use timestamp of .changes file as __DATE__ and __TIME__ to
  avoid unnecessary rebuilds.
* Mon Sep  3 2012 pth@suse.de
- Update to 1.5.13 from OFED 1.5.4.1
* Fri Jul 20 2012 pth@suse.de
- Update to 1.5.12 from OFED 1.5.4.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Fri Jan 28 2011 pth@suse.de
- Provide split provides for update.
* Fri Oct 29 2010 stefan.fent@novell.com
- correct requires to libibumad-devel
- split *-devel package
* Wed Oct 27 2010 jjolly@novell.com
- Many changes to the %%files section
* Tue Oct 26 2010 jjolly@novell.com
- Update to v1.5.7 from OFED 1.5.2
* Sat Mar 20 2010 jjolly@suse.de
- Update to v1.4.4_20090314 from OFED 1.4.2
* Thu Dec 11 2008 jjolly@suse.de
- Updated to v1.4.4_20081207 from OFED 1.4 GA
  - infiniband-diags/grouping: add 10G IP router devid
  - infiniband-diags/ibstat.c: Use UMAD_MAX_DEVICES define
  - infiniband-diags/ibstat.c: remove casting
  - Fix max parameter passed to umad_get_cas_names
  - infiniband-diags/saquery.8: Update saquery man page
  - infiniband-diags/saquery: Support MFTRecord
  - infiniband-diags/saquery: add LFT Record handling
  - infiniband-diags/perfquery: fix constant size warning
  - infiniband-diags/perfquery: if -a is specified loop through
    ports if required and aggregate output
  - perfquery code cleanup
  - infiniband-diags/perfquery: if --loop_ports is specified always
    loop through all ports if desired
  - infinibanf-diags/perfquery: remove single port CA AllPortSelect
    workaround
  - infiniband-diags/perfquery: error out if AllPortSelect is not
    supported
  - tweak notes about port 255 in perfquery manpage
  - infiniband-diags/ibclearerrors: specify -a in call to perfquery
  - infiniband-diags/perfquery: support ehanced port 0 with
  - -loop-ports
  - infiniband-diags/ibsysstat.c: Fix a couple of latent bugs
  - add --loop_ports option to perfquery
  - add more detail to error message on perfquery workaround
  - use 0xff vs. 255 consistently in perfquery
  - add clarification in perfquery manpage
  - infiniband-diags: eliminate compiler warnings
  - infiniband-diags/ibtracert: fix port by direct path resolving
  - man/ibtracert: remove non-existing -e option
  - infiniband-diags/ibclearcounters: remove unrelated -N option
  - man/ibnetdiscover: cleanup non-existing options
  - ibnetdiscover.c: continue processing other ports even if
    smpquery fails on one port
  - Fix some missing node name map substitutions
  - infiniband-diags/src/ibaddr.c: remove unused variables
  - infiniband-diags/src/ibaddr.c: convert GID prints to use
    inet_ntop
  - infiniband-diags/saquery: remove unused variable
  - infiniband-diags/src/saquery.c: convert GID prints to use
    inet_ntop
* Thu Nov 13 2008 ro@suse.de
- excludearch s390 s390x
* Mon Oct 27 2008 jjolly@suse.de
- Updated to version from the OFED 1.4 rc3
* Thu Sep 11 2008 jjolly@suse.de
- Updated to 1.4.1 from the OFED 1.4 RC1
* Tue Mar  4 2008 jjolly@suse.de
- Update to 1.3.6 from the OFED 1.3 GA release
* Wed Feb 13 2008 pth@suse.de
- Run autoreconf
- Pass [foreign] to AM_INIT_AUTOMAKE
- Default for IBPATH is substituted by configure, no need to patch it.
- Update to 1.3.5.
  Changes since 1.2.7 are to numerous to list here, see NEWS and
  ChangeLog for the complete list.
* Mon Aug 20 2007 hvogel@suse.de
- Updated to version from OFED 1.2.5
* Thu Jul 19 2007 hvogel@suse.de
- fix path in the shellscripts
* Wed Jul  4 2007 hvogel@suse.de
- Add GPL COPYING file [#288855]
* Tue Jul  3 2007 hvogel@suse.de
- Downgrade to 1.2.7 because this turned out to be the version
  in OFED 1.2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.3.0
